# SMOTE-variants

The package implements 85 variants of the Synthetic Minority Oversampling Technique (SMOTE). Besides the implementations, an easy to use model selection framework is supplied to enable the rapid evaluation on oversampling techniques on various unseen datasets.

# Citation

The publication and dissemination of this work and its derivatives are going on, please come back in a couple of days or weeks updates.

# Installation

The code 

# Usage

# Adding a new oversampler
